@@ -27,7 +27,7 @@ class PCRecord(CBIRecord):
         f.an(1, 'filler', 1)
         f.an(2, 'record_type', 2, default=u'PC')
         f.an(4, 'sender', 5)
-        f.an(9, 'recipient', 5)
+        f.nu(9, 'recipient', 5)
         f.dt(14, 'creation', 6)
         f.an(20, 'name', 20)
         f.an(40, 'available', 6)
@@ -47,7 +47,7 @@ class EFRecord(CBIRecord):
         f.an(1, 'filler', 1)
         f.an(2, 'record_type', 2, default=u'EF')
         f.an(4, 'sender', 5)
-        f.an(9, 'recipient', 5)
+        f.nu(9, 'recipient', 5)
         f.dt(14, 'creation', 6)
         f.an(20, 'name', 20)
         f.an(40, 'available', 6)
